# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Users\asdfz\Downloads\PyLANDrop\selectfilesdialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SelectFilesDialog(object):
    def setupUi(self, SelectFilesDialog):
        SelectFilesDialog.setObjectName("SelectFilesDialog")
        SelectFilesDialog.resize(390, 383)
        SelectFilesDialog.setAcceptDrops(True)
        self.verticalLayout = QtWidgets.QVBoxLayout(SelectFilesDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.instructionLabel = QtWidgets.QLabel(SelectFilesDialog)
        self.instructionLabel.setObjectName("instructionLabel")
        self.verticalLayout.addWidget(self.instructionLabel)
        self.filesListView = QtWidgets.QListView(SelectFilesDialog)
        self.filesListView.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.filesListView.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.filesListView.setObjectName("filesListView")
        self.verticalLayout.addWidget(self.filesListView)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.addButton = QtWidgets.QPushButton(SelectFilesDialog)
        self.addButton.setObjectName("addButton")
        self.horizontalLayout.addWidget(self.addButton)
        self.removeButton = QtWidgets.QPushButton(SelectFilesDialog)
        self.removeButton.setObjectName("removeButton")
        self.horizontalLayout.addWidget(self.removeButton)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.buttonBox = QtWidgets.QDialogButtonBox(SelectFilesDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(SelectFilesDialog)
        self.buttonBox.accepted.connect(SelectFilesDialog.accept)
        self.buttonBox.rejected.connect(SelectFilesDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(SelectFilesDialog)

    def retranslateUi(self, SelectFilesDialog):
        _translate = QtCore.QCoreApplication.translate
        SelectFilesDialog.setWindowTitle(_translate("SelectFilesDialog", "Select File(s) to be Sent"))
        self.instructionLabel.setText(_translate("SelectFilesDialog", "You can drag files to this window:"))
        self.addButton.setText(_translate("SelectFilesDialog", "Add..."))
        self.removeButton.setText(_translate("SelectFilesDialog", "Remove"))
