# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Users\asdfz\Downloads\PyLANDrop\sendtodialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SendToDialog(object):
    def setupUi(self, SendToDialog):
        SendToDialog.setObjectName("SendToDialog")
        SendToDialog.resize(218, 300)
        self.verticalLayout = QtWidgets.QVBoxLayout(SendToDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.addrLineEdit = QtWidgets.QLineEdit(SendToDialog)
        self.addrLineEdit.setText("")
        self.addrLineEdit.setObjectName("addrLineEdit")
        self.horizontalLayout.addWidget(self.addrLineEdit)
        self.colon = QtWidgets.QLabel(SendToDialog)
        self.colon.setObjectName("colon")
        self.horizontalLayout.addWidget(self.colon)
        self.portLineEdit = QtWidgets.QLineEdit(SendToDialog)
        self.portLineEdit.setText("")
        self.portLineEdit.setMaxLength(5)
        self.portLineEdit.setObjectName("portLineEdit")
        self.horizontalLayout.addWidget(self.portLineEdit)
        self.horizontalLayout.setStretch(0, 3)
        self.horizontalLayout.setStretch(2, 1)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.hostsListView = QtWidgets.QListView(SendToDialog)
        self.hostsListView.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.hostsListView.setObjectName("hostsListView")
        self.verticalLayout.addWidget(self.hostsListView)
        self.buttonBox = QtWidgets.QDialogButtonBox(SendToDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(SendToDialog)
        self.buttonBox.accepted.connect(SendToDialog.accept)
        self.buttonBox.rejected.connect(SendToDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(SendToDialog)

    def retranslateUi(self, SendToDialog):
        _translate = QtCore.QCoreApplication.translate
        SendToDialog.setWindowTitle(_translate("SendToDialog", "Send to"))
        self.addrLineEdit.setPlaceholderText(_translate("SendToDialog", "Address"))
        self.colon.setText(_translate("SendToDialog", ":"))
        self.portLineEdit.setPlaceholderText(_translate("SendToDialog", "Port"))
