# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Users\asdfz\Downloads\PyLANDrop\settingsdialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.4
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SettingsDialog(object):
    def setupUi(self, SettingsDialog):
        SettingsDialog.setObjectName("SettingsDialog")
        SettingsDialog.resize(400, 265)
        self.verticalLayout = QtWidgets.QVBoxLayout(SettingsDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.basicGroupBox = QtWidgets.QGroupBox(SettingsDialog)
        self.basicGroupBox.setObjectName("basicGroupBox")
        self.formLayout_3 = QtWidgets.QFormLayout(self.basicGroupBox)
        self.formLayout_3.setObjectName("formLayout_3")
        self.deviceNameLabel = QtWidgets.QLabel(self.basicGroupBox)
        self.deviceNameLabel.setObjectName("deviceNameLabel")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.deviceNameLabel)
        self.deviceNameLineEdit = QtWidgets.QLineEdit(self.basicGroupBox)
        self.deviceNameLineEdit.setMaxLength(64)
        self.deviceNameLineEdit.setObjectName("deviceNameLineEdit")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.deviceNameLineEdit)
        self.downloadPathLabel = QtWidgets.QLabel(self.basicGroupBox)
        self.downloadPathLabel.setObjectName("downloadPathLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.downloadPathLabel)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.downloadPathLineEdit = QtWidgets.QLineEdit(self.basicGroupBox)
        self.downloadPathLineEdit.setObjectName("downloadPathLineEdit")
        self.horizontalLayout.addWidget(self.downloadPathLineEdit)
        self.downloadPathSelectButton = QtWidgets.QToolButton(self.basicGroupBox)
        self.downloadPathSelectButton.setObjectName("downloadPathSelectButton")
        self.horizontalLayout.addWidget(self.downloadPathSelectButton)
        self.formLayout_3.setLayout(1, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout)
        self.discoverableLabel = QtWidgets.QLabel(self.basicGroupBox)
        self.discoverableLabel.setObjectName("discoverableLabel")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.discoverableLabel)
        self.discoverableCheckBox = QtWidgets.QCheckBox(self.basicGroupBox)
        self.discoverableCheckBox.setText("")
        self.discoverableCheckBox.setObjectName("discoverableCheckBox")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.discoverableCheckBox)
        self.checkForUpdatesLabel = QtWidgets.QLabel(self.basicGroupBox)
        self.checkForUpdatesLabel.setObjectName("checkForUpdatesLabel")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.checkForUpdatesLabel)
        self.checkForUpdatesButton = QtWidgets.QPushButton(self.basicGroupBox)
        self.checkForUpdatesButton.setObjectName("checkForUpdatesButton")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.checkForUpdatesButton)
        self.verticalLayout.addWidget(self.basicGroupBox)
        self.advancedGroupBox = QtWidgets.QGroupBox(SettingsDialog)
        self.advancedGroupBox.setObjectName("advancedGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.advancedGroupBox)
        self.formLayout.setObjectName("formLayout")
        self.serverPortLabel = QtWidgets.QLabel(self.advancedGroupBox)
        self.serverPortLabel.setObjectName("serverPortLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.serverPortLabel)
        self.serverPortLineEdit = QtWidgets.QLineEdit(self.advancedGroupBox)
        self.serverPortLineEdit.setMaxLength(5)
        self.serverPortLineEdit.setObjectName("serverPortLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.serverPortLineEdit)
        self.verticalLayout.addWidget(self.advancedGroupBox)
        self.buttonBox = QtWidgets.QDialogButtonBox(SettingsDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(SettingsDialog)
        self.buttonBox.accepted.connect(SettingsDialog.accept)
        self.buttonBox.rejected.connect(SettingsDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(SettingsDialog)

    def retranslateUi(self, SettingsDialog):
        _translate = QtCore.QCoreApplication.translate
        SettingsDialog.setWindowTitle(_translate("SettingsDialog", "Settings"))
        self.basicGroupBox.setTitle(_translate("SettingsDialog", "Basic"))
        self.deviceNameLabel.setText(_translate("SettingsDialog", "Device Name"))
        self.downloadPathLabel.setText(_translate("SettingsDialog", "Download Path"))
        self.downloadPathSelectButton.setText(_translate("SettingsDialog", "..."))
        self.discoverableLabel.setText(_translate("SettingsDialog", "Discoverable"))
        self.checkForUpdatesLabel.setText(_translate("SettingsDialog", "Check for Updates"))
        self.checkForUpdatesButton.setText(_translate("SettingsDialog", "Check"))
        self.advancedGroupBox.setTitle(_translate("SettingsDialog", "Advanced"))
        self.serverPortLabel.setText(_translate("SettingsDialog", "Server Port"))
